@@ -416,9 +416,13 @@ class Builder:
         return task_list
 
 
-def run_tasks(config_file, task=None, **kwargs):
+def run_tasks(task=None, **kwargs):
+    config_file=kwargs.get("f",None) or kwargs.get("file","jobx.yaml")
+    if "f" in kwargs:
+        kwargs.pop("f")
+    if "file" in kwargs:
+        kwargs.pop("file")
     cfg = load_yaml(config_file, **kwargs)
-    # print(cfg)
     workers_limit = cfg.get('workers_limit', 1)
     delay = cfg.get('delay', 0)
     tasks = Builder.build_task_group(cfg, cfg.get('name', 'Task'), task)
